==> pigment_0.3.2.orig.tar.gz: pigment-0.3.2/pgm/pgmmarshal.h <==

#ifndef __pgm_marshal_MARSHAL_H__
#define __pgm_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:VOID (./pgmmarshal.list:27) */
#define pgm_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:ENUM (./pgmmarshal.list:28) */
#define pgm_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM

/* VOID:BOXED (./pgmmarshal.list:29) */
#define pgm_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED

/* VOID:OBJECT,OBJECT (./pgmmarshal.list:30) */
extern void pgm_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:OBJECT,OBJECT,INT (./pgmmarshal.list:31) */
extern void pgm_marshal_VOID__OBJECT_OBJECT_INT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* BOOLEAN:ENUM,UINT (./pgmmarshal.list:32) */
extern void pgm_marshal_BOOLEAN__ENUM_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* BOOLEAN:FLOAT,FLOAT,FLOAT,ENUM,UINT (./pgmmarshal.list:33) */
extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
                                                              const GValue *param_values,
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);

/* BOOLEAN:FLOAT,FLOAT,FLOAT,UINT (./pgmmarshal.list:34) */
extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
                                                         const GValue *param_values,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);

G_END_DECLS

#endif /* __pgm_marshal_MARSHAL_H__ */

==> pigment_0.3.5.orig.tar.gz: pigment-0.3.5/pgm/pgmmarshal.h <==

#ifndef __pgm_marshal_MARSHAL_H__
#define __pgm_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:VOID (./pgmmarshal.list:27) */
#define pgm_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:ENUM (./pgmmarshal.list:28) */
#define pgm_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM

/* VOID:BOXED (./pgmmarshal.list:29) */
#define pgm_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED

/* BOOLEAN:BOXED (./pgmmarshal.list:30) */
extern void pgm_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

/* VOID:OBJECT,OBJECT (./pgmmarshal.list:31) */
extern void pgm_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:OBJECT,OBJECT,INT (./pgmmarshal.list:32) */
extern void pgm_marshal_VOID__OBJECT_OBJECT_INT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* BOOLEAN:ENUM,UINT (./pgmmarshal.list:33) */
extern void pgm_marshal_BOOLEAN__ENUM_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* BOOLEAN:FLOAT,FLOAT,FLOAT,ENUM,UINT (./pgmmarshal.list:34) */
extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
                                                              const GValue *param_values,
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);

/* BOOLEAN:FLOAT,FLOAT,FLOAT,UINT (./pgmmarshal.list:35) */
extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
                                                         const GValue *param_values,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);

/* VOID:UINT,UINT,POINTER (./pgmmarshal.list:36) */
extern void pgm_marshal_VOID__UINT_UINT_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

G_END_DECLS

#endif /* __pgm_marshal_MARSHAL_H__ */
